@@ -61,7 +61,7 @@ weight.mat<-function(phy, edges, Rate.mat, root.state, simmap.tree=FALSE, scaleH
 					}
 					else{
 						#For the root:
-						oldregime=oldregime
+						oldregime=root.state
 					}	
 					newregime=which(edges[i,6:(k+5)]==1)
 					if(oldregime==newregime){
@@ -137,7 +137,7 @@ weight.mat<-function(phy, edges, Rate.mat, root.state, simmap.tree=FALSE, scaleH
 					}
 					else{
 						#For the root:
-						oldregime=oldregime
+						oldregime=root.state
 					}	
 					newregime=which(edges[i,6:(k+5)]==1)
 					if(oldregime==newregime){
